#!/bin/bash
set -e

source build-env.sh

echo \#\#\# is libffi-dev installed?
dpkg -s libffi-dev > /dev/null 2>&1
if [ ! $? ]
then
    sudo apt install libffi-dev
else
    echo \#\#\# YES
fi

if [ ! -d "src/Python-$PY_VER" ]
then
    pushd src
    wget https://www.python.org/ftp/python/$PY_VER/Python-$PY_VER.tgz
    tar -xf Python-$PY_VER.tgz
    rm Python-$PY_VER.tgz
    popd
fi

# wget https://www.python.org/ftp/python/3.5.9/Python-3.5.9.tgz
# wget https://www.python.org/ftp/python/2.7.18/Python-2.7.18.tgz

echo \#\#\# Does "$INSTALL_DIR/lib/libpython$PY_MAJ.$PY_MIN.a" exist?
if [ ! -f "$INSTALL_DIR/lib/libpython$PY_MAJ.$PY_MIN.a" ]
then
    rm -rf build/local-python$PY_VER
    mkdir build/local-python$PY_VER
    pushd build/local-python$PY_VER

    mkdir ssl
    ln -s /usr/include/ ssl/include
    ln -s /usr/lib/x86_64-linux-gnu ssl/lib
    $SCRIPTPATH/src/Python-$PY_VER/configure --with-openssl=`pwd`/ssl --prefix=$INSTALL_DIR

    make -j14 install > build.out
    popd
else
    echo \#\#\# YES
fi

echo \#\#\# Does "$INSTALL_ARM_DIR/lib/libpython$PY_MAJ.$PY_MIN.a" exist?
if [ ! -f "$INSTALL_ARM_DIR/lib/libpython$PY_MAJ.$PY_MIN.a" ]
then
    source $SCRIPTPATH/cross-compile-env.sh $1

    rm -rf build/python$PY_VER
    mkdir build/python$PY_VER
    pushd build/python$PY_VER

    rm -rf config.site
    echo ac_cv_file__dev_ptmx=no >> config.site
    echo ac_cv_file__dev_ptc=no >> config.site
    export CONFIG_SITE=config.site

    mkdir ssl
    ln -s $INSTALL_ARM_DIR/include/ ssl/include
    ln -s $INSTALL_ARM_DIR/lib ssl/lib
    $SCRIPTPATH/src/Python-$PY_VER/configure --host $TARGET --build=$BUILD_ON --with-openssl=`pwd`/ssl --disable-ipv6  --without-ensurepip --prefix="$INSTALL_ARM_DIR"

    make -j16 install > build.out
    popd
else
    echo \#\#\# YES
fi
